@@ -12,4 +12,4 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""Supporting code common to multiple fetchers/checks."""
+"""Supporting code common to multiple fetchers/checks/reports."""
